==> sdd.fiservapi.client-0.1.17-sources.jar: ar/com/sdd/fiservapi/model/response/Error.java <==
package ar.com.sdd.fiservapi.model.response;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class Error implements Serializable {

    @JsonProperty("code")
    private String code;

    @JsonProperty("message")
    private String message;

    @JsonProperty("details")
    private Details details;


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public Details getDetails() {
        return details;
    }

    public void setDetails(Details details) {
        this.details = details;
    }

    @Override
    public String toString() {
        return "Error [" +
                ((code != null) ? "code='" + code + "', " : "") +
                ((message != null) ? "message='" + message + "', " : "") +
                ((details != null) ? "details=" + details + ", " : "") +
                "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Error error = (Error) o;
        return Objects.equals(code, error.code) && Objects.equals(message, error.message) && Objects.equals(details, error.details);
    }

    @Override
    public int hashCode() {
        return Objects.hash(code, message, details);
    }
}

==> sdd.fiservapi.client-0.1.21-sources.jar: ar/com/sdd/fiservapi/model/response/Error.java <==
package ar.com.sdd.fiservapi.model.response;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
import java.util.Arrays;
import java.util.List;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class Error implements Serializable {

    @JsonProperty("code")
    private String code;

    @JsonProperty("message")
    private String message;

    @JsonProperty("details")
    private List<Details> details;

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public List<Details>getDetails() {
        return details;
    }

    public void setDetails(List<Details>details) {
        this.details = details;
    }

    @Override
    public String toString() {
        return "Error [" +
                ((code != null) ? "code='" + code + "', " : "") +
                ((message != null) ? "message='" + message + "', " : "") +
                ((details != null) ? "details=" + Arrays.toString(details.toArray()) + ", " : "") +
                "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Error error = (Error) o;
        return Objects.equals(code, error.code) && Objects.equals(message, error.message) && Objects.equals(details, error.details);
    }

    @Override
    public int hashCode() {
        return Objects.hash(code, message, details);
    }
}
